--
--
--    Copyright (C) 2015  Henry Weidman
--
--    henry@weidmanenterprises.com
--
--    This is free software. You may share it or change
--    it. This software is distributed with no warranty. 
--
--
-- NAME
--		IndexCards
--
-- SYNOPSIS
--		psql -f IndexCards.sql
-- 
-- DESCRIPTION
--		SQL code to create the database tables and indexes 
--
-- FILES
--		IndexCards.sql - This file
--
-- 

DROP TABLE decks CASCADE;

CREATE TABLE decks (
   num SERIAL,
   DeckName varchar
);

ALTER TABLE decks ADD PRIMARY KEY (num);
CREATE UNIQUE INDEX deck_num_index ON decks USING  btree (num);


DROP TABLE indexcards ;

CREATE TABLE indexcards (
   id   SERIAL PRIMARY key,
   dnum int REFERENCES decks(num),
   cardnum    integer,
   text varchar
);

CREATE UNIQUE INDEX card_index ON indexcards USING  btree (id);

CREATE INDEX card_number_index ON indexcards USING  btree (cardnum);

CREATE INDEX card_text_index ON indexcards USING  btree (text);


INSERT INTO decks VALUES (1, 'Linux Commands');

INSERT INTO indexcards VALUES (1, 1, 1, 'cd');

INSERT INTO indexcards VALUES (2, 1, 1, 'change directory');

DROP TABLE textIn;

CREATE TABLE textIn (
   front varchar,
   back  varchar
);

DROP TABLE flashcmd;


CREATE TABLE flashcmd (
   command varchar,
   cmdDate date,
   info    varchar,
   n SERIAL PRIMARY KEY
);


--
-- If any .csv file cannot be read, postgres throws an exception
-- which is handled here.  If a file can be read, but is empty,
-- the code detects that the file is empty. 
--
CREATE OR REPLACE FUNCTION importfileNotEmpty() RETURNS int AS $$
DECLARE
  status	int := 0;
  recCount	int := 0;
BEGIN

  --
  -- Start of exception handler
  --
  BEGIN
     DELETE FROM countText;
     COPY countText FROM '/home/classdb/sql/import.csv';
     SELECT count(*) INTO recCount FROM countText;
     IF recCount = 0
     THEN
       status := -1;
     END IF;

  EXCEPTION
     WHEN OTHERS THEN status := -2;
  END;
  --
  -- End of exception handler
  --

  return status;

END;
$$ LANGUAGE plpgsql;


CREATE OR REPLACE FUNCTION import() RETURNS int AS $$
DECLARE
  status	int := 0;
  fileCount	int := 0;
  recCount	int := 0;
  startNum	int := 1000;
  idnum         int;
  dnum          int;
  cardnum       int := 1;
  importRec     RECORD;

BEGIN

   status := importFileNotEmpty();

   IF status = 0
   THEN

     SELECT max(num) INTO dnum FROM decks;

     dnum := dnum + 1;

     INSERT INTO decks VALUES (dnum, 'Imported File');

     DELETE FROM textIn;

     COPY textIn FROM '/home/classdb/sql/import.csv' WITH DELIMITER AS ',';

     SELECT max(id) INTO idnum FROM indexcards;

     idnum := idnum + 1;

     SELECT max(num) INTO dnum FROM decks;
     
     FOR importRec IN SELECT * FROM textin LOOP

      INSERT INTO indexcards VALUES (idnum, dnum, cardnum, importRec.front);

      idnum := idnum + 1;
      cardnum := cardnum + 1;

      INSERT INTO indexcards VALUES (idnum, dnum, cardnum, importRec.back);

      idnum := idnum + 1;
      cardnum := cardnum + 1;

    END LOOP;

    PERFORM setval('indexcards_id_seq', idnum);


  END IF;

   return status;
END;
$$ LANGUAGE plpgsql;



CREATE OR REPLACE FUNCTION flashCmd() RETURNS trigger AS $flashCmd$
DECLARE
  status	int := 1;

BEGIN

        CASE UPPER(NEW.command)
           WHEN 'IMPORT' THEN 
             status := import();
             NEW.INFO := 'IMPORT DONE';  
           ELSE
             NEW.info := 'Valid Commands are: IMPORT';
        END CASE;
      
        NEW.cmdDate := current_date;

        return NEW;
END;
$flashCmd$ LANGUAGE plpgsql;

CREATE TRIGGER flashCmd BEFORE INSERT ON flashcmd
    FOR EACH ROW EXECUTE PROCEDURE flashCmd();


CREATE OR REPLACE FUNCTION deckDel() RETURNS trigger AS $deckDel$
DECLARE
  n int;

BEGIN
        n := OLD.num;

        DELETE FROM indexcards WHERE dnum = n;

        return OLD;
END;
$deckDel$ LANGUAGE plpgsql;

CREATE TRIGGER deckDelete BEFORE DELETE ON decks
    FOR EACH ROW EXECUTE PROCEDURE deckDel();




