--
--
--    Copyright (C) 2015  Henry Weidman
--
--    henry@weidmanenterprises.com
--
--    This is free software. You may share it or change
--    it. This software is distributed with no warranty. 
--
--
--
-- NAME
--	calc
--
-- SYNOPSIS
--	INSERT INTO calculate VALUES ('n', 'n', 'o');
-- 
-- DESCRIPTION
--	This is a simple procedure that demonstrates how
--      database triggers work.  Inserting values into the
--      calculate table triggers the calc() procedure which
--      performs the desired calculation and places the 
--      result in the calculate table.
--
--      Note that the factorial operation requires an integer,
--      i int, as coded below.
--
-- FILES
--	calculator.sql - This file
--


DROP TABLE calcinfo;

CREATE TABLE calcinfo (
    operator	varchar,
    description	varchar,
    n		serial PRIMARY KEY
);

INSERT INTO calcinfo VALUES('+', 'Add');
INSERT INTO calcinfo VALUES('-', 'Subtract');
INSERT INTO calcinfo VALUES('*', 'Multiply');
INSERT INTO calcinfo VALUES('/', 'Divide');
INSERT INTO calcinfo VALUES('^', 'Raise x to the y power');
INSERT INTO calcinfo VALUES('sqrt', 'Square root of x');
INSERT INTO calcinfo VALUES('sine', 'Sine of x');
INSERT INTO calcinfo VALUES('!', 'Factorial of x');


DROP TABLE calculate;

CREATE TABLE calculate (
    x real,
    y real,
    o varchar,
    result real,
    n serial PRIMARY KEY
);


CREATE OR REPLACE FUNCTION calc() RETURNS trigger AS $calc$
DECLARE
  i int; -- for operations that require an integer

    BEGIN

        IF NEW.x IS NULL THEN
            RAISE EXCEPTION 'x is null';
        END IF;

        IF NEW.o IS NULL THEN
            RAISE EXCEPTION 'operator is null';
        END IF;

        IF NEW.o = '!'
        THEN
          i := NEW.x; -- factorial requires an integer
        END IF;

        NEW.result = 0;
	CASE NEW.o
          WHEN '+' THEN NEW.result := NEW.x + NEW.y;	
          WHEN '-' THEN NEW.result := NEW.x - NEW.y;	
          WHEN '*' THEN NEW.result := NEW.x * NEW.y;	
          WHEN 'x' THEN NEW.result := NEW.x * NEW.y;	
          WHEN 'X' THEN NEW.result := NEW.x * NEW.y;	
          WHEN '/' THEN 
             IF NEW.y <> 0 THEN
               NEW.result := NEW.x / NEW.y;
             END IF;
             IF NEW.y = 0 THEN
                NEW.o := '?';
             END IF;
          WHEN '^' THEN NEW.result := power(NEW.x, NEW.y);		
          WHEN 'sqrt' THEN NEW.result := sqrt(NEW.x); 
          WHEN 'sine' THEN NEW.result := sin(NEW.x);
          WHEN '!' THEN NEW.result := i !;
          ELSE NEW.o := '?';
	END CASE;
        
        RETURN NEW;
    END;
$calc$ LANGUAGE plpgsql;



CREATE TRIGGER calc BEFORE INSERT OR UPDATE ON calculate
    FOR EACH ROW EXECUTE PROCEDURE calc();


