--
-- PostgreSQL database dump
--

-- Dumped from database version 12.2 (Ubuntu 12.2-4)
-- Dumped by pg_dump version 12.2 (Ubuntu 12.2-4)

SET statement_timeout = 0;
SET lock_timeout = 0;
SET idle_in_transaction_session_timeout = 0;
SET client_encoding = 'UTF8';
SET standard_conforming_strings = on;
SELECT pg_catalog.set_config('search_path', '', false);
SET check_function_bodies = false;
SET xmloption = content;
SET client_min_messages = warning;
SET row_security = off;

--
-- Name: admincmd(); Type: FUNCTION; Schema: public; Owner: classdb
--

CREATE FUNCTION public.admincmd() RETURNS trigger
    LANGUAGE plpgsql
    AS $$
DECLARE
    ret int;

    BEGIN
        --raise notice 'AdminCmd()';
        
        ret := 1;

        CASE UPPER(NEW.command)
           WHEN 'BACKUP' THEN 
             ret := backup();
             NEW.INFO := 'BACKUP DONE';  
           WHEN 'RESTORE' THEN 
             ret := restore();
             ret := restoreFlashCards();
             NEW.INFO := 'RESTORE DONE'; 
           WHEN 'REPORT' THEN
             ret := membersReport(); 
             NEW.INFO := 'REPORT DONE';
           WHEN 'PG_DUMP' THEN
             ret := 1;
           ELSE
             NEW.info := 'Valid Commands are: BACKUP, RESTORE, REPORT';
        END CASE;

        IF ret < 0 
        THEN
          NEW.info := '***** One or more csv file is empty';
        END IF;
        
        
        --raise notice 'current_date';

        NEW.cmdDate := current_date;

       

        return NEW;
    END;
$$;


ALTER FUNCTION public.admincmd() OWNER TO classdb;

--
-- Name: backup(); Type: FUNCTION; Schema: public; Owner: classdb
--

CREATE FUNCTION public.backup() RETURNS integer
    LANGUAGE plpgsql
    AS $$
DECLARE
  status int := 0;

BEGIN
   COPY members TO '/home/classdb/sql/members.csv' WITH DELIMITER AS '~';
   COPY address TO '/home/classdb/sql/address.csv' WITH DELIMITER AS '~';
   COPY phone TO '/home/classdb/sql/phone.csv' WITH DELIMITER AS '~';
   COPY email TO '/home/classdb/sql/email.csv' WITH DELIMITER AS '~';
   COPY decks TO '/home/classdb/sql/decks.csv' WITH DELIMITER AS '~';
   COPY indexcards TO '/home/classdb/sql/indexcards.csv' WITH DELIMITER AS '~';
   return status;
END;
$$;


ALTER FUNCTION public.backup() OWNER TO classdb;

--
-- Name: deckdel(); Type: FUNCTION; Schema: public; Owner: classdb
--

CREATE FUNCTION public.deckdel() RETURNS trigger
    LANGUAGE plpgsql
    AS $$
DECLARE
  n int;

BEGIN
        n := OLD.num;

        DELETE FROM indexcards WHERE dnum = n;

        return OLD;
END;
$$;


ALTER FUNCTION public.deckdel() OWNER TO classdb;

--
-- Name: deletemember(); Type: FUNCTION; Schema: public; Owner: classdb
--

CREATE FUNCTION public.deletemember() RETURNS trigger
    LANGUAGE plpgsql
    AS $$
DECLARE

  n int;

    BEGIN
        n := OLD.num;

        -- raise notice 'Delete %', OLD.num;

        DELETE FROM address WHERE anum = n;
       
        DELETE FROM phone WHERE pnum = n;
     
        DELETE FROM email WHERE enum = n;

        RETURN OLD;
    END;

$$;


ALTER FUNCTION public.deletemember() OWNER TO classdb;

--
-- Name: filenotempty(); Type: FUNCTION; Schema: public; Owner: classdb
--

CREATE FUNCTION public.filenotempty() RETURNS integer
    LANGUAGE plpgsql
    AS $$
DECLARE
  status	int := 0;
  recCount	int := 0;
BEGIN

  --
  -- Start of exception handler
  --
  BEGIN
     DELETE FROM countText;
     COPY countText FROM '/home/classdb/sql/members.csv';
     SELECT count(*) INTO recCount FROM countText;
     IF recCount = 0
     THEN
       status := -1;
     END IF;

     DELETE FROM countText;
     COPY countText FROM '/home/classdb/sql/address.csv';
     SELECT count(*) INTO recCount FROM countText;
     IF recCount = 0
     THEN
       status := -1;
     END IF;

     DELETE FROM countText;
     COPY countText FROM '/home/classdb/sql/phone.csv';
     SELECT count(*) INTO recCount FROM countText;
     IF recCount = 0
     THEN
       status := -1;
     END IF;

     DELETE FROM countText;
     COPY countText FROM '/home/classdb/sql/email.csv';
     SELECT count(*) INTO recCount FROM countText;
     IF recCount = 0
     THEN
       status := -1;
     END IF;

  EXCEPTION
     WHEN OTHERS THEN status := -2;
  END;
  --
  -- End of exception handler
  --

  return status;

END;
$$;


ALTER FUNCTION public.filenotempty() OWNER TO classdb;

--
-- Name: flashcmd(); Type: FUNCTION; Schema: public; Owner: classdb
--

CREATE FUNCTION public.flashcmd() RETURNS trigger
    LANGUAGE plpgsql
    AS $$
DECLARE
  status	int := 1;

BEGIN

        CASE UPPER(NEW.command)
           WHEN 'IMPORT' THEN 
             status := import();
             NEW.INFO := 'IMPORT DONE';  
           ELSE
             NEW.info := 'Valid Commands are: IMPORT';
        END CASE;
      
        NEW.cmdDate := current_date;

        return NEW;
END;
$$;


ALTER FUNCTION public.flashcmd() OWNER TO classdb;

--
-- Name: flashfilesnotempty(); Type: FUNCTION; Schema: public; Owner: classdb
--

CREATE FUNCTION public.flashfilesnotempty() RETURNS integer
    LANGUAGE plpgsql
    AS $$
DECLARE
  status	int := 0;
  recCount	int := 0;
BEGIN

  --
  -- Start of exception handler
  --
  BEGIN
     DELETE FROM countText;
     COPY countText FROM '/home/classdb/sql/decks.csv';
     SELECT count(*) INTO recCount FROM countText;
     IF recCount = 0
     THEN
       status := -1;
     END IF;

     DELETE FROM countText;
     COPY countText FROM '/home/classdb/sql/indexcards.csv';
     SELECT count(*) INTO recCount FROM countText;
     IF recCount = 0
     THEN
       status := -1;
     END IF;

  EXCEPTION
     WHEN OTHERS THEN status := -2;
  END;
  --
  -- End of exception handler
  --

  return status;

END;
$$;


ALTER FUNCTION public.flashfilesnotempty() OWNER TO classdb;

--
-- Name: import(); Type: FUNCTION; Schema: public; Owner: classdb
--

CREATE FUNCTION public.import() RETURNS integer
    LANGUAGE plpgsql
    AS $$
DECLARE
  status	int := 0;
  fileCount	int := 0;
  recCount	int := 0;
  startNum	int := 1000;
  idnum         int;
  dnum          int;
  cardnum       int := 1;
  importRec     RECORD;

BEGIN

   status := importFileNotEmpty();

   IF status = 0
   THEN

     SELECT max(num) INTO dnum FROM decks;

     dnum := dnum + 1;

     INSERT INTO decks VALUES (dnum, 'Imported File');

     DELETE FROM textIn;

     COPY textIn FROM '/home/classdb/sql/import.csv' WITH DELIMITER AS ',';

     SELECT max(id) INTO idnum FROM indexcards;

     idnum := idnum + 1;

     SELECT max(num) INTO dnum FROM decks;
     
     FOR importRec IN SELECT * FROM textin LOOP

      INSERT INTO indexcards VALUES (idnum, dnum, cardnum, importRec.front);

      idnum := idnum + 1;
      cardnum := cardnum + 1;

      INSERT INTO indexcards VALUES (idnum, dnum, cardnum, importRec.back);

      idnum := idnum + 1;
      cardnum := cardnum + 1;

    END LOOP;

    PERFORM setval('indexcards_id_seq', idnum);


  END IF;

   return status;
END;
$$;


ALTER FUNCTION public.import() OWNER TO classdb;

--
-- Name: importfilenotempty(); Type: FUNCTION; Schema: public; Owner: classdb
--

CREATE FUNCTION public.importfilenotempty() RETURNS integer
    LANGUAGE plpgsql
    AS $$
DECLARE
  status	int := 0;
  recCount	int := 0;
BEGIN

  --
  -- Start of exception handler
  --
  BEGIN
     DELETE FROM countText;
     COPY countText FROM '/home/classdb/sql/import.csv';
     SELECT count(*) INTO recCount FROM countText;
     IF recCount = 0
     THEN
       status := -1;
     END IF;

  EXCEPTION
     WHEN OTHERS THEN status := -2;
  END;
  --
  -- End of exception handler
  --

  return status;

END;
$$;


ALTER FUNCTION public.importfilenotempty() OWNER TO classdb;

--
-- Name: isnumeric(text); Type: FUNCTION; Schema: public; Owner: classdb
--

CREATE FUNCTION public.isnumeric(text) RETURNS boolean
    LANGUAGE plpgsql
    AS $_$
DECLARE
  status boolean;
BEGIN
  SELECT $1 ~ '^[0-9]+$' INTO status;
  return status;
END;
$_$;


ALTER FUNCTION public.isnumeric(text) OWNER TO classdb;

--
-- Name: membersreport(); Type: FUNCTION; Schema: public; Owner: classdb
--

CREATE FUNCTION public.membersreport() RETURNS integer
    LANGUAGE plpgsql
    AS $$
DECLARE
  status 	int;
  txt    	varchar;
  memRec 	RECORD;
  addressRec	RECORD;
  phoneRec      RECORD;
  emailRec      RECORD;
BEGIN
  status := 1;

  DELETE FROM report;

  FOR memRec IN SELECT * FROM members LOOP
     txt := memRec.num || ' ' || memRec.firstname || ' ' || memRec.lastname;
     INSERT INTO report VALUES (txt);

     SELECT * FROM address INTO addressRec WHERE address.anum = memRec.num;
     txt := addressRec.street || ', ' || addressRec.city || ', ' || addressRec.state || ', ' || addressRec.zip;
     INSERT INTO report VALUES (txt);

     FOR phoneRec IN SELECT * FROM phone WHERE phone.pnum = memRec.num LOOP
        txt := phoneRec.phoneNumber;
        INSERT INTO report VALUES (txt);
     END LOOP;

     FOR emailRec IN SELECT * FROM email WHERE email.enum = memRec.num LOOP
        txt := emailRec.emailAddr;
        INSERT INTO report VALUES (txt);
     END LOOP;

     INSERT INTO report VALUES ('  ');

 
  END LOOP;

       COPY report TO '/home/classdb/sql/report.txt';


  return status;
END;
$$;


ALTER FUNCTION public.membersreport() OWNER TO classdb;

--
-- Name: newmember(); Type: FUNCTION; Schema: public; Owner: classdb
--

CREATE FUNCTION public.newmember() RETURNS trigger
    LANGUAGE plpgsql
    AS $$
DECLARE

  n int;
  recCount int;
  lastNm varchar;
  firstNm varchar;
  addressRec RECORD;
  phoneRec RECORD;

    BEGIN

        -- raise notice 'BEGIN %', NEW.num;

        IF NEW.num IS NULL THEN
            RAISE EXCEPTION 'member number is null';
        END IF;
        
        -- raise notice 'num %', NEW.num;

        SELECT firstname INTO firstNm FROM members WHERE members.num=NEW.num;

        INSERT INTO address VALUES(NEW.num, 'street', 'city', 'NY', '12345');
        INSERT INTO phone VALUES(NEW.num, DEFAULT, '');
        INSERT INTO email VALUES(NEW.num, DEFAULT, firstNm);

        -- raise notice 'Inserts Done %', NEW.num;

        lastNm := UPPER(NEW.lastname);

        SELECT count(*) INTO n FROM members WHERE UPPER(lastname) = lastNm;
         -- raise notice 'num %', n;

        IF n > 0 
        THEN
          SELECT min(members.num) INTO n FROM members WHERE UPPER(lastname) = lastNm;
          SELECT * INTO addressRec FROM address WHERE anum = n;
          UPDATE address SET street = addressRec.street WHERE anum = NEW.num;
          UPDATE address SET city = addressRec.city WHERE anum = NEW.num;
          UPDATE address SET state = addressRec.state WHERE anum = NEW.num;
          UPDATE address SET zip = addressRec.zip WHERE anum = NEW.num;

          recCount := 0;
          FOR phoneRec IN SELECT * FROM phone WHERE pnum = n
          LOOP
            IF recCount = 0
            THEN
              UPDATE phone SET phoneNumber = phoneRec.phoneNumber WHERE pnum = NEW.num;
            END IF;
            recCount := recCount + 1;
          END LOOP;

        END IF;

        RETURN NEW;
    END;
$$;


ALTER FUNCTION public.newmember() OWNER TO classdb;

--
-- Name: newphone(); Type: FUNCTION; Schema: public; Owner: classdb
--

CREATE FUNCTION public.newphone() RETURNS trigger
    LANGUAGE plpgsql
    AS $$
DECLARE
  formatPhone varchar;

BEGIN

  -- raise notice 'New Phone: %', NEW.PhoneNumber;
  IF isNumeric(NEW.PhoneNumber)
  THEN
    formatPhone := '(' || substring(NEW.PhoneNumber from 1 for 3) || ') ' || substring(NEW.PhoneNumber from 4 for 3) ||
                   '-' || substring(NEW.PhoneNumber from 7 for 4);
    NEW.PhoneNumber := formatPhone;
  END IF;

  -- raise notice 'New Phone: %', formatPhone;
  -- raise notice 'New Phone: %', NEW.PhoneNumber;
  -- raise notice 'New Phone: Finished';

  RETURN NEW;
END;
$$;


ALTER FUNCTION public.newphone() OWNER TO classdb;

--
-- Name: restore(); Type: FUNCTION; Schema: public; Owner: classdb
--

CREATE FUNCTION public.restore() RETURNS integer
    LANGUAGE plpgsql
    AS $$
DECLARE
  status	int := 0;
  fileCount	int := 0;
  recCount	int := 0;
  startNum	int := 1000;

BEGIN

   status := fileNotEmpty();

   IF status = 0
   THEN
     DELETE FROM members;
     COPY members FROM '/home/classdb/sql/members.csv' WITH DELIMITER AS '~';

     SELECT max(num) INTO startNum FROM members;
     PERFORM setval('members_num_seq', startNum);


     DELETE FROM address;
     COPY address FROM '/home/classdb/sql/address.csv' WITH DELIMITER AS '~';
     DELETE FROM phone;
     COPY phone FROM '/home/classdb/sql/phone.csv' WITH DELIMITER AS '~';
     DELETE FROM email;
     COPY email FROM '/home/classdb/sql/email.csv' WITH DELIMITER AS '~';
   END IF;

   return status;
END;
$$;


ALTER FUNCTION public.restore() OWNER TO classdb;

--
-- Name: restoreflashcards(); Type: FUNCTION; Schema: public; Owner: classdb
--

CREATE FUNCTION public.restoreflashcards() RETURNS integer
    LANGUAGE plpgsql
    AS $$
DECLARE
  status	int := 0;
  fileCount	int := 0;
  recCount	int := 0;
  startNum	int := 1000;

BEGIN

   status := flashfilesNotEmpty();

   IF status = 0
   THEN
     DROP TRIGGER IF EXISTS deckDelete ON decks CASCADE;

     DELETE FROM indexcards;

     DELETE FROM decks;

     COPY decks FROM '/home/classdb/sql/decks.csv' WITH DELIMITER AS '~';

     COPY indexcards FROM '/home/classdb/sql/indexcards.csv' WITH DELIMITER AS '~';

     CREATE TRIGGER deckDelete BEFORE DELETE ON decks
        FOR EACH ROW EXECUTE PROCEDURE deckDel();

   END IF;


   return status;
END;
$$;


ALTER FUNCTION public.restoreflashcards() OWNER TO classdb;

--
-- Name: verifydump(); Type: FUNCTION; Schema: public; Owner: classdb
--

CREATE FUNCTION public.verifydump() RETURNS integer
    LANGUAGE plpgsql
    AS $$
DECLARE
  recCount int := 0;
  strA     date;
  strB     varchar;
  status   int := 1;
BEGIN
     strB := 'classdbBackup performed';
     strA := current_date;
     INSERT INTO admincmd VALUES ('pg_dump', strA, strB);

     return status;
END;
$$;


ALTER FUNCTION public.verifydump() OWNER TO classdb;

SET default_tablespace = '';

SET default_table_access_method = heap;

--
-- Name: address; Type: TABLE; Schema: public; Owner: classdb
--

CREATE TABLE public.address (
    anum integer NOT NULL,
    street character varying,
    city character varying,
    state character varying,
    zip character varying
);


ALTER TABLE public.address OWNER TO classdb;

--
-- Name: admincmd; Type: TABLE; Schema: public; Owner: classdb
--

CREATE TABLE public.admincmd (
    command character varying,
    cmddate date,
    info character varying,
    n integer NOT NULL
);


ALTER TABLE public.admincmd OWNER TO classdb;

--
-- Name: admincmd_n_seq; Type: SEQUENCE; Schema: public; Owner: classdb
--

CREATE SEQUENCE public.admincmd_n_seq
    AS integer
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


ALTER TABLE public.admincmd_n_seq OWNER TO classdb;

--
-- Name: admincmd_n_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: classdb
--

ALTER SEQUENCE public.admincmd_n_seq OWNED BY public.admincmd.n;


--
-- Name: admininfo; Type: TABLE; Schema: public; Owner: classdb
--

CREATE TABLE public.admininfo (
    command character varying,
    n integer NOT NULL
);


ALTER TABLE public.admininfo OWNER TO classdb;

--
-- Name: admininfo_n_seq; Type: SEQUENCE; Schema: public; Owner: classdb
--

CREATE SEQUENCE public.admininfo_n_seq
    AS integer
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


ALTER TABLE public.admininfo_n_seq OWNER TO classdb;

--
-- Name: admininfo_n_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: classdb
--

ALTER SEQUENCE public.admininfo_n_seq OWNED BY public.admininfo.n;


--
-- Name: counttext; Type: TABLE; Schema: public; Owner: classdb
--

CREATE TABLE public.counttext (
    textin text
);


ALTER TABLE public.counttext OWNER TO classdb;

--
-- Name: decks; Type: TABLE; Schema: public; Owner: classdb
--

CREATE TABLE public.decks (
    num integer NOT NULL,
    deckname character varying
);


ALTER TABLE public.decks OWNER TO classdb;

--
-- Name: decks_num_seq; Type: SEQUENCE; Schema: public; Owner: classdb
--

CREATE SEQUENCE public.decks_num_seq
    AS integer
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


ALTER TABLE public.decks_num_seq OWNER TO classdb;

--
-- Name: decks_num_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: classdb
--

ALTER SEQUENCE public.decks_num_seq OWNED BY public.decks.num;


--
-- Name: email; Type: TABLE; Schema: public; Owner: classdb
--

CREATE TABLE public.email (
    enum integer NOT NULL,
    snum integer NOT NULL,
    emailaddr character varying
);


ALTER TABLE public.email OWNER TO classdb;

--
-- Name: email_snum_seq; Type: SEQUENCE; Schema: public; Owner: classdb
--

CREATE SEQUENCE public.email_snum_seq
    AS integer
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


ALTER TABLE public.email_snum_seq OWNER TO classdb;

--
-- Name: email_snum_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: classdb
--

ALTER SEQUENCE public.email_snum_seq OWNED BY public.email.snum;


--
-- Name: flashcmd; Type: TABLE; Schema: public; Owner: classdb
--

CREATE TABLE public.flashcmd (
    command character varying,
    cmddate date,
    info character varying,
    n integer NOT NULL
);


ALTER TABLE public.flashcmd OWNER TO classdb;

--
-- Name: flashcmd_n_seq; Type: SEQUENCE; Schema: public; Owner: classdb
--

CREATE SEQUENCE public.flashcmd_n_seq
    AS integer
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


ALTER TABLE public.flashcmd_n_seq OWNER TO classdb;

--
-- Name: flashcmd_n_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: classdb
--

ALTER SEQUENCE public.flashcmd_n_seq OWNED BY public.flashcmd.n;


--
-- Name: indexcards; Type: TABLE; Schema: public; Owner: classdb
--

CREATE TABLE public.indexcards (
    id integer NOT NULL,
    dnum integer,
    cardnum integer,
    text character varying
);


ALTER TABLE public.indexcards OWNER TO classdb;

--
-- Name: indexcards_id_seq; Type: SEQUENCE; Schema: public; Owner: classdb
--

CREATE SEQUENCE public.indexcards_id_seq
    AS integer
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


ALTER TABLE public.indexcards_id_seq OWNER TO classdb;

--
-- Name: indexcards_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: classdb
--

ALTER SEQUENCE public.indexcards_id_seq OWNED BY public.indexcards.id;


--
-- Name: members; Type: TABLE; Schema: public; Owner: classdb
--

CREATE TABLE public.members (
    num integer NOT NULL,
    firstname character varying,
    lastname character varying
);


ALTER TABLE public.members OWNER TO classdb;

--
-- Name: members_num_seq; Type: SEQUENCE; Schema: public; Owner: classdb
--

CREATE SEQUENCE public.members_num_seq
    AS integer
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


ALTER TABLE public.members_num_seq OWNER TO classdb;

--
-- Name: members_num_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: classdb
--

ALTER SEQUENCE public.members_num_seq OWNED BY public.members.num;


--
-- Name: phone; Type: TABLE; Schema: public; Owner: classdb
--

CREATE TABLE public.phone (
    pnum integer NOT NULL,
    snum integer NOT NULL,
    phonenumber character varying
);


ALTER TABLE public.phone OWNER TO classdb;

--
-- Name: phone_snum_seq; Type: SEQUENCE; Schema: public; Owner: classdb
--

CREATE SEQUENCE public.phone_snum_seq
    AS integer
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


ALTER TABLE public.phone_snum_seq OWNER TO classdb;

--
-- Name: phone_snum_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: classdb
--

ALTER SEQUENCE public.phone_snum_seq OWNED BY public.phone.snum;


--
-- Name: report; Type: TABLE; Schema: public; Owner: classdb
--

CREATE TABLE public.report (
    text character varying
);


ALTER TABLE public.report OWNER TO classdb;

--
-- Name: textin; Type: TABLE; Schema: public; Owner: classdb
--

CREATE TABLE public.textin (
    front character varying,
    back character varying
);


ALTER TABLE public.textin OWNER TO classdb;

--
-- Name: admincmd n; Type: DEFAULT; Schema: public; Owner: classdb
--

ALTER TABLE ONLY public.admincmd ALTER COLUMN n SET DEFAULT nextval('public.admincmd_n_seq'::regclass);


--
-- Name: admininfo n; Type: DEFAULT; Schema: public; Owner: classdb
--

ALTER TABLE ONLY public.admininfo ALTER COLUMN n SET DEFAULT nextval('public.admininfo_n_seq'::regclass);


--
-- Name: decks num; Type: DEFAULT; Schema: public; Owner: classdb
--

ALTER TABLE ONLY public.decks ALTER COLUMN num SET DEFAULT nextval('public.decks_num_seq'::regclass);


--
-- Name: email snum; Type: DEFAULT; Schema: public; Owner: classdb
--

ALTER TABLE ONLY public.email ALTER COLUMN snum SET DEFAULT nextval('public.email_snum_seq'::regclass);


--
-- Name: flashcmd n; Type: DEFAULT; Schema: public; Owner: classdb
--

ALTER TABLE ONLY public.flashcmd ALTER COLUMN n SET DEFAULT nextval('public.flashcmd_n_seq'::regclass);


--
-- Name: indexcards id; Type: DEFAULT; Schema: public; Owner: classdb
--

ALTER TABLE ONLY public.indexcards ALTER COLUMN id SET DEFAULT nextval('public.indexcards_id_seq'::regclass);


--
-- Name: members num; Type: DEFAULT; Schema: public; Owner: classdb
--

ALTER TABLE ONLY public.members ALTER COLUMN num SET DEFAULT nextval('public.members_num_seq'::regclass);


--
-- Name: phone snum; Type: DEFAULT; Schema: public; Owner: classdb
--

ALTER TABLE ONLY public.phone ALTER COLUMN snum SET DEFAULT nextval('public.phone_snum_seq'::regclass);


--
-- Data for Name: address; Type: TABLE DATA; Schema: public; Owner: classdb
--

COPY public.address (anum, street, city, state, zip) FROM stdin;
1000	24 Bickel Court	Sterling	VA	20165
1001	123 New Street	New City	NY	12345
1002	FPO	San Francisco	CA	12345
1003	99 Cat Street	Cat City	NY	12345
1004	24 Bickel Court	Sterling	VA	20165
\.


--
-- Data for Name: admincmd; Type: TABLE DATA; Schema: public; Owner: classdb
--

COPY public.admincmd (command, cmddate, info, n) FROM stdin;
backup	2020-05-14	BACKUP DONE	1
restore	2020-05-14	RESTORE DONE	2
help	2020-05-14	Valid Commands are: BACKUP, RESTORE, REPORT	3
report	2020-05-14	REPORT DONE	4
pg_dump	2020-05-14	classdbBackup performed	5
\.


--
-- Data for Name: admininfo; Type: TABLE DATA; Schema: public; Owner: classdb
--

COPY public.admininfo (command, n) FROM stdin;
BACKUP	1
RESTORE	2
REPORT	3
\.


--
-- Data for Name: counttext; Type: TABLE DATA; Schema: public; Owner: classdb
--

COPY public.counttext (textin) FROM stdin;
1~1~1~cd
2~1~1~change directory
\.


--
-- Data for Name: decks; Type: TABLE DATA; Schema: public; Owner: classdb
--

COPY public.decks (num, deckname) FROM stdin;
1	Linux Commands
\.


--
-- Data for Name: email; Type: TABLE DATA; Schema: public; Owner: classdb
--

COPY public.email (enum, snum, emailaddr) FROM stdin;
1000	1	Henry@gmail.com
1001	2	New@gmail.com
1002	3	WTDoor@USSVance.mil
1003	4	Phoebe@Cat.com
1004	5	Kathleen@gmail.com
\.


--
-- Data for Name: flashcmd; Type: TABLE DATA; Schema: public; Owner: classdb
--

COPY public.flashcmd (command, cmddate, info, n) FROM stdin;
\.


--
-- Data for Name: indexcards; Type: TABLE DATA; Schema: public; Owner: classdb
--

COPY public.indexcards (id, dnum, cardnum, text) FROM stdin;
1	1	1	cd
2	1	1	change directory
\.


--
-- Data for Name: members; Type: TABLE DATA; Schema: public; Owner: classdb
--

COPY public.members (num, firstname, lastname) FROM stdin;
1000	Henry	Weidman
1001	New	Member
1002	WT	Door
1003	Phoebe	Cat
1004	Kathleen	Weidman
\.


--
-- Data for Name: phone; Type: TABLE DATA; Schema: public; Owner: classdb
--

COPY public.phone (pnum, snum, phonenumber) FROM stdin;
1000	1	(703) 555-1212
1001	2	(512) 555-1212
1002	3	(800) 123-4567
1003	4	(800) 899-6470
1004	5	(703) 555-1212
1000	7	(571) 555-1212
\.


--
-- Data for Name: report; Type: TABLE DATA; Schema: public; Owner: classdb
--

COPY public.report (text) FROM stdin;
1000 Henry Weidman
24 Bickel Court, Sterling, VA, 20165
(703) 555-1212
(571) 555-1212
Henry@gmail.com
  
1001 New Member
123 New Street, New City, NY, 12345
(512) 555-1212
New@gmail.com
  
1002 WT Door
FPO, San Francisco, CA, 12345
(800) 123-4567
WTDoor@USSVance.mil
  
1003 Phoebe Cat
99 Cat Street, Cat City, NY, 12345
(800) 899-6470
Phoebe@Cat.com
  
1004 Kathleen Weidman
24 Bickel Court, Sterling, VA, 20165
(703) 555-1212
Kathleen@gmail.com
  
\.


--
-- Data for Name: textin; Type: TABLE DATA; Schema: public; Owner: classdb
--

COPY public.textin (front, back) FROM stdin;
\.


--
-- Name: admincmd_n_seq; Type: SEQUENCE SET; Schema: public; Owner: classdb
--

SELECT pg_catalog.setval('public.admincmd_n_seq', 5, true);


--
-- Name: admininfo_n_seq; Type: SEQUENCE SET; Schema: public; Owner: classdb
--

SELECT pg_catalog.setval('public.admininfo_n_seq', 3, true);


--
-- Name: decks_num_seq; Type: SEQUENCE SET; Schema: public; Owner: classdb
--

SELECT pg_catalog.setval('public.decks_num_seq', 1, false);


--
-- Name: email_snum_seq; Type: SEQUENCE SET; Schema: public; Owner: classdb
--

SELECT pg_catalog.setval('public.email_snum_seq', 16, true);


--
-- Name: flashcmd_n_seq; Type: SEQUENCE SET; Schema: public; Owner: classdb
--

SELECT pg_catalog.setval('public.flashcmd_n_seq', 1, false);


--
-- Name: indexcards_id_seq; Type: SEQUENCE SET; Schema: public; Owner: classdb
--

SELECT pg_catalog.setval('public.indexcards_id_seq', 1, false);


--
-- Name: members_num_seq; Type: SEQUENCE SET; Schema: public; Owner: classdb
--

SELECT pg_catalog.setval('public.members_num_seq', 1004, true);


--
-- Name: phone_snum_seq; Type: SEQUENCE SET; Schema: public; Owner: classdb
--

SELECT pg_catalog.setval('public.phone_snum_seq', 17, true);


--
-- Name: address address_index; Type: CONSTRAINT; Schema: public; Owner: classdb
--

ALTER TABLE ONLY public.address
    ADD CONSTRAINT address_index PRIMARY KEY (anum);


--
-- Name: admincmd admincmd_pkey; Type: CONSTRAINT; Schema: public; Owner: classdb
--

ALTER TABLE ONLY public.admincmd
    ADD CONSTRAINT admincmd_pkey PRIMARY KEY (n);


--
-- Name: admininfo admininfo_pkey; Type: CONSTRAINT; Schema: public; Owner: classdb
--

ALTER TABLE ONLY public.admininfo
    ADD CONSTRAINT admininfo_pkey PRIMARY KEY (n);


--
-- Name: decks decks_pkey; Type: CONSTRAINT; Schema: public; Owner: classdb
--

ALTER TABLE ONLY public.decks
    ADD CONSTRAINT decks_pkey PRIMARY KEY (num);


--
-- Name: email email_table_index; Type: CONSTRAINT; Schema: public; Owner: classdb
--

ALTER TABLE ONLY public.email
    ADD CONSTRAINT email_table_index PRIMARY KEY (enum, snum);


--
-- Name: flashcmd flashcmd_pkey; Type: CONSTRAINT; Schema: public; Owner: classdb
--

ALTER TABLE ONLY public.flashcmd
    ADD CONSTRAINT flashcmd_pkey PRIMARY KEY (n);


--
-- Name: indexcards indexcards_pkey; Type: CONSTRAINT; Schema: public; Owner: classdb
--

ALTER TABLE ONLY public.indexcards
    ADD CONSTRAINT indexcards_pkey PRIMARY KEY (id);


--
-- Name: members members_pkey; Type: CONSTRAINT; Schema: public; Owner: classdb
--

ALTER TABLE ONLY public.members
    ADD CONSTRAINT members_pkey PRIMARY KEY (num);


--
-- Name: phone phone_table_index; Type: CONSTRAINT; Schema: public; Owner: classdb
--

ALTER TABLE ONLY public.phone
    ADD CONSTRAINT phone_table_index PRIMARY KEY (pnum, snum);


--
-- Name: card_index; Type: INDEX; Schema: public; Owner: classdb
--

CREATE UNIQUE INDEX card_index ON public.indexcards USING btree (id);


--
-- Name: card_number_index; Type: INDEX; Schema: public; Owner: classdb
--

CREATE INDEX card_number_index ON public.indexcards USING btree (cardnum);


--
-- Name: card_text_index; Type: INDEX; Schema: public; Owner: classdb
--

CREATE INDEX card_text_index ON public.indexcards USING btree (text);


--
-- Name: deck_num_index; Type: INDEX; Schema: public; Owner: classdb
--

CREATE UNIQUE INDEX deck_num_index ON public.decks USING btree (num);


--
-- Name: member_num_index; Type: INDEX; Schema: public; Owner: classdb
--

CREATE UNIQUE INDEX member_num_index ON public.members USING btree (num);


--
-- Name: admincmd admincmd; Type: TRIGGER; Schema: public; Owner: classdb
--

CREATE TRIGGER admincmd BEFORE INSERT ON public.admincmd FOR EACH ROW EXECUTE FUNCTION public.admincmd();


--
-- Name: decks deckdelete; Type: TRIGGER; Schema: public; Owner: classdb
--

CREATE TRIGGER deckdelete BEFORE DELETE ON public.decks FOR EACH ROW EXECUTE FUNCTION public.deckdel();


--
-- Name: members deletemember; Type: TRIGGER; Schema: public; Owner: classdb
--

CREATE TRIGGER deletemember BEFORE DELETE ON public.members FOR EACH ROW EXECUTE FUNCTION public.deletemember();


--
-- Name: flashcmd flashcmd; Type: TRIGGER; Schema: public; Owner: classdb
--

CREATE TRIGGER flashcmd BEFORE INSERT ON public.flashcmd FOR EACH ROW EXECUTE FUNCTION public.flashcmd();


--
-- Name: members newmember; Type: TRIGGER; Schema: public; Owner: classdb
--

CREATE TRIGGER newmember AFTER INSERT ON public.members FOR EACH ROW EXECUTE FUNCTION public.newmember();


--
-- Name: phone newphone; Type: TRIGGER; Schema: public; Owner: classdb
--

CREATE TRIGGER newphone BEFORE INSERT ON public.phone FOR EACH ROW EXECUTE FUNCTION public.newphone();


--
-- Name: phone updphone; Type: TRIGGER; Schema: public; Owner: classdb
--

CREATE TRIGGER updphone BEFORE UPDATE ON public.phone FOR EACH ROW EXECUTE FUNCTION public.newphone();


--
-- Name: address address_anum_fkey; Type: FK CONSTRAINT; Schema: public; Owner: classdb
--

ALTER TABLE ONLY public.address
    ADD CONSTRAINT address_anum_fkey FOREIGN KEY (anum) REFERENCES public.members(num);


--
-- Name: email email_enum_fkey; Type: FK CONSTRAINT; Schema: public; Owner: classdb
--

ALTER TABLE ONLY public.email
    ADD CONSTRAINT email_enum_fkey FOREIGN KEY (enum) REFERENCES public.members(num);


--
-- Name: indexcards indexcards_dnum_fkey; Type: FK CONSTRAINT; Schema: public; Owner: classdb
--

ALTER TABLE ONLY public.indexcards
    ADD CONSTRAINT indexcards_dnum_fkey FOREIGN KEY (dnum) REFERENCES public.decks(num);


--
-- Name: phone phone_pnum_fkey; Type: FK CONSTRAINT; Schema: public; Owner: classdb
--

ALTER TABLE ONLY public.phone
    ADD CONSTRAINT phone_pnum_fkey FOREIGN KEY (pnum) REFERENCES public.members(num);


--
-- PostgreSQL database dump complete
--

